@@ -1,4 +1,4 @@
-"""Messages for AMQP"""
+"""AMQP Messages."""
 # Copyright (C) 2007-2008 Barry Pederson <bp@barryp.org>
 #
 # This library is free software; you can redistribute it and/or
@@ -32,7 +32,68 @@ __all__ = ['Message']
 
 
 class Message(GenericContent):
-    """A Message for use with the Channnel.basic_* methods."""
+    """A Message for use with the Channel.basic_* methods.
+
+    Expected arg types
+
+        body: string
+        children: (not supported)
+
+    Keyword properties may include:
+
+        content_type: shortstr
+            MIME content type
+
+        content_encoding: shortstr
+            MIME content encoding
+
+        application_headers: table
+            Message header field table, a dict with string keys,
+            and string | int | Decimal | datetime | dict values.
+
+        delivery_mode: octet
+            Non-persistent (1) or persistent (2)
+
+        priority: octet
+            The message priority, 0 to 9
+
+        correlation_id: shortstr
+            The application correlation identifier
+
+        reply_to: shortstr
+            The destination to reply to
+
+        expiration: shortstr
+            Message expiration specification
+
+        message_id: shortstr
+            The application message identifier
+
+        timestamp: datetime.datetime
+            The message timestamp
+
+        type: shortstr
+            The message type name
+
+        user_id: shortstr
+            The creating user id
+
+        app_id: shortstr
+            The creating application id
+
+        cluster_id: shortstr
+            Intra-cluster routing identifier
+
+        Unicode bodies are encoded according to the 'content_encoding'
+        argument. If that's None, it's set to 'UTF-8' automatically.
+
+        Example::
+
+            msg = Message('hello world',
+                            content_type='text/plain',
+                            application_headers={'foo': 7})
+    """
+
     CLASS_ID = Basic.CLASS_ID
 
     #: Instances of this class have these attributes, which
@@ -59,66 +120,6 @@ class Message(GenericContent):
     delivery_info = None
 
     def __init__(self, body='', children=None, channel=None, **properties):
-        """Expected arg types
-
-            body: string
-            children: (not supported)
-
-        Keyword properties may include:
-
-            content_type: shortstr
-                MIME content type
-
-            content_encoding: shortstr
-                MIME content encoding
-
-            application_headers: table
-                Message header field table, a dict with string keys,
-                and string | int | Decimal | datetime | dict values.
-
-            delivery_mode: octet
-                Non-persistent (1) or persistent (2)
-
-            priority: octet
-                The message priority, 0 to 9
-
-            correlation_id: shortstr
-                The application correlation identifier
-
-            reply_to: shortstr
-                The destination to reply to
-
-            expiration: shortstr
-                Message expiration specification
-
-            message_id: shortstr
-                The application message identifier
-
-            timestamp: datetime.datetime
-                The message timestamp
-
-            type: shortstr
-                The message type name
-
-            user_id: shortstr
-                The creating user id
-
-            app_id: shortstr
-                The creating application id
-
-            cluster_id: shortstr
-                Intra-cluster routing identifier
-
-        Unicode bodies are encoded according to the 'content_encoding'
-        argument. If that's None, it's set to 'UTF-8' automatically.
-
-        example::
-
-            msg = Message('hello world',
-                            content_type='text/plain',
-                            application_headers={'foo': 7})
-
-        """
         super(Message, self).__init__(**properties)
         self.body = body
         self.channel = channel
